/**
 * @file
 *  日期组件, 依赖 eonasdan-bootstrap-datetimepicker, moment, moment-locales
 * @module widget-calendar.js
 * @version 1.0.0
 */

'use strict';

import React    from 'react'
import ReactDOM from 'react-dom'
import Widget   from './widget'

export default class Calendar extends Widget {

  constructor(props) {
    super(props);
    this.onClick = this.onClick.bind(this);
  }

  componentDidMount() {

    let node = $(ReactDOM.findDOMNode(this)).find('input');

    node.datetimepicker({
      locale: this.locale(),
      format: this.format(),
      defaultDate: this.props.data.defaults,
      ignoreReadonly: true
    });

    if (this.props.data.textMin) {
      node.data('DateTimePicker').minDate(moment(this.props.data.textMin, this.format()));
    }

    if (this.props.data.textMax) {
      node.data('DateTimePicker').maxDate(moment(this.props.data.textMax, this.format()));
    }

    node.on('dp.change', event => {
      this.change(event.date.format(this.format()), event.target.name);
    });
  }

  componentDidUpdate(prevProps) {

    let node = $(ReactDOM.findDOMNode(this)).find('input'), option = {};

    if (this.props.data.defaults !== prevProps.data.defaults) {
      option.defaultDate = this.props.data.defaults;
    }

    if (this.props.data.textMin && prevProps.data.textMin !== this.props.data.textMin) {

      let textMin = moment(this.props.data.textMin, this.format());

      // 缺省值要比最小值大
      if (this.props.data.defaults && moment(this.props.data.defaults, this.format()).isBefore(textMin)) {
        delete option['defaultDate'];
      }
      node.data('DateTimePicker').minDate(textMin);
    }

    if (this.props.data.textMax && prevProps.data.textMax !== this.props.data.textMax) {

      let textMax = moment(this.props.data.textMax, this.format());

      // 缺省值要比最大值小
      if (this.props.data.defaults && moment(this.props.data.defaults, this.format()).isAfter(textMin)) {
        delete option['defaultDate'];
      }
      node.data('DateTimePicker').maxDate(textMax);
    }

    if (!_.isEmpty(option)) {
      node.data('DateTimePicker').options(option);
    }
  }

  render() {
    return React.DOM.div({className: this.className()}, this.icon(), this.widget());
  }

  className() {
    return 'input' + (this.props.data.disabled === 'true' ? ' state-disabled' : '');
  }

  getValue() {
    if (this.value()) {
      return moment().format(this.value(), this.format());
    }

    return '';
  }

  format() {
    return this.props.data.textDateFormat || 'YYYY-MM-DD';
  }

  locale() {
    return this.props.data.locale || 'zh-cn';
  }

  widget() {
    return React.DOM.input({
      type: 'text',
      disabled: this.disabled(),
      readOnly: true,
      placeholder: this.props.data.textPlaceholder,
      value: this.getValue(),
      name: this.props.data.name,
      onClick: this.onClick
    });
  }

  onClick() {
    $(ReactDOM.findDOMNode(this)).find('input').data('DateTimePicker').show();
  }
}
