/**
 * @file
 * @module widget-icon.js
 * @version 1.0.0
 */

'use strict';

import React    from 'react'
import Widget   from './widget'
import IconJson from './icon.json'

export default class Icon extends Widget {

  constructor(props) {
    super(props);
    this.onChange = this.onChange.bind(this);
    this.onClick = this.onClick.bind(this);
  }

  render() {
    return React.DOM.div({className: this.className()},
      this.icon(),
      this.widget(),
      this.dropdown()
    );
  }

  className() {
    return 'input icon dropup' + (this.props.data.disabled == 'true' ? ' state-disabled' : '');
  }

  widget() {

    return React.DOM.input({
      className: 'dropdown-toggle', 'data-toggle': 'dropdown',
      type: 'text',
      disabled: this.disabled(),
      placeholder: this.props.data.textPlaceholder,
      onChange: this.onChange,
      value: this.value() || '',
      name: this.props.data.name
    });
  }

  dropdown() {
    return React.DOM.ul({className: 'dropdown-menu dropdown-menu-up'},
      React.DOM.li({},
        React.DOM.div({className: 'picker'},
          IconJson[this.props.iconType].map(item => {
              return React.DOM.a({className: 'picker-item', 'data-icon': item, key: item, onClick: this.onClick},
                React.DOM.i({className: this.props.iconPrefix + item})
              );
            }
          )
        )
      )
    );
  }

  onClick(event) {

    event.preventDefault();

    let icon = event.currentTarget.getAttribute('data-icon');
    this.change(icon, this.props.data.name);
  }

  onChange(event) {
    this.change(event.target.value, event.target.name);
  }

}

Icon.defaultProps = {
  iconType: 'fontwesome',     // glyphicons | fontwesome
  iconPrefix: 'fa fa-fw fa-'  // 'glyphicon glyphicon-' | 'fa fa-fw fa-'
};