/**
 * @file
 * @module widget-image.js
 * @version 1.0.0
 */

'use strict';

import React    from 'react'
import Widget   from './widget'
import CONST    from './constant'

export default class Image  extends Widget {

  constructor(props) {
    super(props);
    this.onChange = this.onChange.bind(this);
  }

  render () {

    this.props.data.fileAccept = this.props.data.fileAccept || 'image/*';
    this.props.data.fileMultiple = this.props.data.fileMultiple || 'multiple';

    return React.DOM.div(null, this.widget());
  }

  widget () {

    // 横向最多显示3张图片
    let width = 12 / this.getValue().length;
    width = width < 4 ? 4 : width;

    return this.getValue().map(function (file) {
      return React.DOM.div({className: 'col-sm-' + width, style: {padding: '1px'}},
        React.DOM.image({src: this.src(file), style: {width: '100%'}},
          React.DOM.ul({
            style: {
              left: 0,
              top: '90%',
              zIndex: 1,
              padding: 0,
              width: '100%',
              marginTop: '-18px',
              textAlign: 'center',
              position: 'absolute',
              transition: 'all 0.2s ease-in-out'
            }
          }, this.getSelectButton(file), this.getRemoveButton(file))
        )
      )
    }.bind(this));
  }

  getValue () {
    if (!this.value() || _.isEmpty(this.value())) {
      return [{}];
    }
    return this.value();
  }

  getSelectButton (file) {
    if (this.disabled()) {
      return null;
    }

    return React.DOM.li({style: {display: 'inline-block', margin: '0 5px'}},
      React.DOM.i({
        className: 'fa fa-border fa-plus',
        style: {
          color: '#eee',
          borderWidth: '2px',
          borderColor: '#eee',
          width: '25px'
        },
        'data-action': 'select',
        'data-id': file.id,
        onClick: this.onClick,
        onMouseOver: this.onMouseover,
        onMouseOut: this.onMouseout
      }),
      React.DOM.input({
        style: {display: 'none'},
        type: 'file',
        accept: this.props.data.fileAccept,
        multiple: this.props.data.fileMultiple,
        onChange: this.onChange
      })
    );
  }

  getRemoveButton (file) {
    if (_.isEmpty(file)) {
      return null;
    }

    if (this.disabled()) {
      return null;
    }

    return React.DOM.li({style: {display: 'inline-block', margin: '0 5px'}},
      React.DOM.i({
        className: 'fa fa-border fa-trash',
        style: {
          color: '#eee',
          borderWidth: '2px',
          borderColor: '#eee',
          width: '25px'
        },
        'data-action': 'remove',
        'data-id': file.id,
        onClick: this.onClick,
        onMouseOver: this.onMouseover,
        onMouseOut: this.onMouseout
      })
    );
  }

  src (file) {
    return _.isEmpty(file) ? CONST.Config.SampleImage : CONST.Config.FileImageAPI + file.id;
  }

  onClick (event) {
    let action = $(event.target).attr('data-action')
      , id = $(event.target).attr('data-id');

    if (action == 'select') {
      this.current = id;
      return $(event.target).next().trigger('click');
    }

    if (action == 'remove') {
      let files = _.reject(this.getValue(), function (item) {
        return item.id == id;
      });

      this.change(files, this.props.data.name);
    }
  }

  onMouseover (event) {
    $(event.target).css({color: '#e74c3c', 'border-color': '#e74c3c'});
  }

  onMouseout (event) {
    $(event.target).css({color: '#eee', 'border-color': '#eee'});
  }

  onChange (event) {
    this.upload(event);
  }

  onProcess (progress) {
  }

  onFinish (error, result) {
    if (error) {
      return this.onError(error);
    }

    // 其余的照片不动, 只替换选择的图片
    let files = [], item = result.data[0];
    _.each(this.getValue(), function (file) {
      if (file.id == this.current) {
        files.push({id: item._id, name: item.name, type: item.contentType, length: item.length});
      } else {
        files.push(file);
      }
    }.bind(this));

    // 多余的照片补充道最后
    for (let i = 1; i < result.data.length; i++) {
      item = result.data[i];
      files.push({id: item._id, name: item.name, type: item.contentType, length: item.length});
    }

    this.change(files, this.props.data.name)
  }
}
