/**
 * @file
 * @module widget-input.js
 * @version 1.0.0
 */

'use strict';

import React    from 'react'
import Widget   from './widget'

export default class Input extends Widget {

  constructor(props) {
    super(props);
    this.onChange = this.onChange.bind(this);
  }

  render() {
    return React.DOM.div({className: this.className()}, this.icon(), this.widget());
  }

  className() {
    return 'input' + (this.props.data.disabled === 'true' ? ' state-disabled' : '');
  }

  getValue() {
    if (_.isObject(this.value())) {
      return _.isEmpty(this.value()) ? '' : JSON.stringify(this.value());
    }

    return this.value() || '';
  }

  widget() {

    let style = null;

    // 输入框在视图模式时，显示为DIV，好让很长的内容也能够折行显示完整
    if (this.disabled()) {

      // 如果左边有图标，那么留出图标的位置
      if (this.props.data.textIcon && this.props.data.textIconAppend !== 'append') {
        style = {paddingLeft: 45};
      }

      return React.DOM.div({className: 'input-readonly', style: style}, this.getValue());
    }

    return React.DOM.input({
      type: 'text',
      placeholder: this.props.data.textPlaceholder,
      onChange: this.onChange,
      value: this.getValue(),
      name: this.props.data.name
    });
  }

  onChange(event) {
    this.change(event.target.value, event.target.name);
  }

}
