/**
 * @file 表单组件父类
 * @module widget.js
 * @author r2space@gmail.com
 * @version 1.0.0
 */

'use strict';

import React    from 'react'
import ReactDOM from 'react-dom'
import CONST    from './constant'

export default class Widget extends React.Component {

  constructor(props) {
    super(props);
  }

  icon() {
    if (!this.props.data.textIcon) {
      return null;
    }

    // 图标显示的位置 append: 在前面显示 prepend: 在后端显示
    let append = 'icon-' + (this.props.data.textIconAppend === 'append' ? 'append' : 'prepend')
      , icon = 'fa-' + this.props.data.textIcon;

    return React.DOM.i({className: append + ' fa ' + icon});
  }

  value() {
    return _.isUndefined(this.props.data.value)
      ? this.props.data.defaults
      : this.props.data.value;
  }

  disabled() {
    if (this.props.option.mode === CONST.MODE.VIEW) {
      return 'disabled';
    }

    if (this.props.option.mode === CONST.MODE.READONLY) {
      return 'disabled';
    }

    return this.boolean(this.props.data.disabled) ? 'disabled' : '';
  }

  change(value, name) {
    this.props.emit(CONST.EVENT.CHANGE, {
      value: value,
      name: name,
      col: this.props.data.col,
      row: this.props.data.row
    }, ReactDOM.findDOMNode(this));
  }

  /**
   * 获取文字数，一个汉字计数2，英文字母计数1
   * @param str
   * @returns {number}
   */
  count(str) {
    if (!str) {
      return 0;
    }

    let len = 0;
    for (let i = 0; i < str.length; i++) {
      if (str.charCodeAt(i) > 255) len++;
      len++;
    }
    return len;
  }

  /**
   * 字符串转换为Boolean
   * @param string
   * @returns {*}
   */
  boolean(string) {
    if (_.isNull(string) || _.isUndefined(string)) {
      return false;
    }

    if (_.isBoolean(string)) {
      return string;
    }

    switch (string.toLowerCase().trim()) {
      case 'true':
      case 'yes':
      case 'on':
      case '1':
        return true;
      case 'false':
      case 'no':
      case 'off':
      case '0':
      case null:
        return false;
      default:
        return true;
    }
  }

  number(string) {
    let result = Number(string);
    return _.isNaN(result) ? 0 : result;
  }

  normalize(option) {
    return Widget.normalize(option);
  }

  /**
   * 上传文件
   * TODO: 支持CDN
   * @param event
   * @returns {boolean}
   */
  upload(event) {
    let files = event.target.files;
    if (!files || files.length <= 0) {
      return false;
    }

    let formData = new FormData();
    for (let i = 0; i < files.length; i++) {
      formData.append('files', files[i]);
    }

    light.multipart(
      CONST.Config.FileUploadAPI, {data: this.props.data.fileOption}, formData, this.onFinish, this.onProcess
    );
  }

};

Widget.defaultProps = {
  control: {}
};

Widget.normalize = function (option) {
  if (!option) {
    return option;
  }

  if (_.isObject(option)) {
    return option;
  }

  let match = option.match(/^(.*)[ ]*:[ ]*(.*)$/);
  if (match) {
    return {value: match[1], title: match[2]};
  }

  return {value: option, title: option};
};

Widget.guid = () => {
  return light.util.guid8();
};

Widget.clone = (val) => {
  return light.util.clone(val);
};